==> zio-aws-apigateway_2.13-5.17.104.2-sources.jar: zio/aws/apigateway/model/GetDocumentationPartsResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetDocumentationPartsResponse(
    position: Option[String] = None,
    items: Option[Iterable[zio.aws.apigateway.model.DocumentationPart]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.GetDocumentationPartsResponse = {
    import GetDocumentationPartsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.GetDocumentationPartsResponse
      .builder()
      .optionallyWith(position.map(value => value: java.lang.String))(
        _.position
      )
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.GetDocumentationPartsResponse.ReadOnly =
    zio.aws.apigateway.model.GetDocumentationPartsResponse.wrap(buildAwsValue())
}
object GetDocumentationPartsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.GetDocumentationPartsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.GetDocumentationPartsResponse =
      zio.aws.apigateway.model.GetDocumentationPartsResponse(
        position.map(value => value),
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def position: Option[String]
    def items: Option[List[zio.aws.apigateway.model.DocumentationPart.ReadOnly]]
    def getPosition: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("position", position)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.apigateway.model.DocumentationPart.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.GetDocumentationPartsResponse
  ) extends zio.aws.apigateway.model.GetDocumentationPartsResponse.ReadOnly {
    override val position: Option[String] =
      scala.Option(impl.position()).map(value => value: String)
    override val items
        : Option[List[zio.aws.apigateway.model.DocumentationPart.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.apigateway.model.DocumentationPart.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.GetDocumentationPartsResponse
  ): zio.aws.apigateway.model.GetDocumentationPartsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigateway_2.13-6.20.97.2-sources.jar: zio/aws/apigateway/model/GetDocumentationPartsResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetDocumentationPartsResponse(
    position: Optional[String] = Optional.Absent,
    items: Optional[Iterable[zio.aws.apigateway.model.DocumentationPart]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.GetDocumentationPartsResponse = {
    import GetDocumentationPartsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.GetDocumentationPartsResponse
      .builder()
      .optionallyWith(position.map(value => value: java.lang.String))(
        _.position
      )
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.GetDocumentationPartsResponse.ReadOnly =
    zio.aws.apigateway.model.GetDocumentationPartsResponse.wrap(buildAwsValue())
}
object GetDocumentationPartsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.GetDocumentationPartsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.GetDocumentationPartsResponse =
      zio.aws.apigateway.model.GetDocumentationPartsResponse(
        position.map(value => value),
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def position: Optional[String]
    def items
        : Optional[List[zio.aws.apigateway.model.DocumentationPart.ReadOnly]]
    def getPosition: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("position", position)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.apigateway.model.DocumentationPart.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.GetDocumentationPartsResponse
  ) extends zio.aws.apigateway.model.GetDocumentationPartsResponse.ReadOnly {
    override val position: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.position())
      .map(value => value: String)
    override val items
        : Optional[List[zio.aws.apigateway.model.DocumentationPart.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.apigateway.model.DocumentationPart.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.GetDocumentationPartsResponse
  ): zio.aws.apigateway.model.GetDocumentationPartsResponse.ReadOnly =
    new Wrapper(impl)
}
